<?php

/*
 * copyright (c) 2010 MDBitz - Matthew John Denton - mdbitz.com
 *
 * This file is part of WordPress Amazon Associate Plugin.
 *
 * WordPress Amazon Associate is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * WordPress Amazon Associate is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with WordPress Amazon Associate.
 * If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * Amazon Product
 *
 * This file contains the class AmazonProduct
 *
 * @author Matthew John Denton <matt@mdbitz.com>
 * @package com.mdbitz.wordpress.amazon_associate
 */

/**
 * AmazonProduct is a utility class to easily ouput Amazon Products
 *
 * @package com.mdbitz.wordpress.amazon_associate
 */
class AmazonProduct {

    /**
     * Ouput Amazon Product Link
     * 
     * @global WPAA $wpaa
     *
     * @param string $content Link Text
     * @param string $id Product Id
     * @param string $type Id Type
     * @param string $target link target
     */
    public static function link($content, $id, $type = "ASIN", $target = "_blank") {
        global $wpaa;
        $output_str = $content;
        if (!is_null($id)) {
            $result = $wpaa->getAPI()->lookup($id, $type);
            if ($result->isSuccess() && isset($result->Items[0])) {
                $output_str = '<a href="' . urldecode($result->Items[0]->DetailPageURL) . '" target="' . $target . '">' . $content . '</a>';
            }
        }
        echo $output_str;
    }

    /**
     * Ouput Amazon Product Image
     *
     * @global WPAA $wpaa
     *
     * @param string $content Link Text
     * @param string $id Product Id
     * @param string $size Image Size
     * @param boolean $link Should Image be a Link
     * @param string $type Id Type
     * @param string $target link target
     */
    public static function image($content, $id, $size="medium", $link = false, $type = "ASIN", $target = "_blank") {
        global $wpaa;
        $output_str = $content;
        if (!is_null($id)) {
            $result = $wpaa->getAPI()->lookup($id, $type, array(AmazonProduct_ResponseGroup::ITEM_ATTRIBUTES, AmazonProduct_ResponseGroup::IMAGES));
            if ($result->isSuccess() && isset($result->Items[0])) {
                $size = strtolower($size);
                $image = null;
                switch ($size) {
                    case "small":
                        $image = $result->Items[0]->SmallImage;
                        break;
                    case "large":
                        $image = $result->Items[0]->LargeImage;
                        break;
                    default :
                        $image = $result->Items[0]->MediumImage;
                        break;
                }
                $output_str = '';
                if ($link) {
                    $output_str = '<a href="' . urldecode($result->Items[0]->DetailPageURL) . '" target="' . $target . '">';
                }
                if (!is_null($image)) {
                    $output_str .= $image->toHTML();
                } else {
                    $output_str .= $content;
                }
                if ($link) {
                    $output_str .= '</a>';
                }
            }
        }
        echo $output_str;
    }

}