<?php
/*
 * copyright (c) 2010 MDBitz - Matthew John Denton - mdbitz.com
 *
 * This file is part of WordPress Amazon Associate Plugin.
 *
 * WordPress Amazon Associate is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * WordPress Amazon Associate is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with WordPress Amazon Associate.
 * If not, see <http://www.gnu.org/licenses/>.
*/

/**
 * WPAA_ShortCodeHandler
 *
 * This file contains the class WPAA_ShortCodeHandler
 *
 * @author Matthew John Denton <matt@mdbitz.com>
 * @package com.mdbitz.wordpress.amazon_associate
 */

/**
 * Short Code Handler Class for WordPress Amazon Associate plugin
 *
 * @package com.mdbitz.wordpress.amazon_associate
 */
class WPAA_ShortCodeHandler {

    /**
     * APaPi library instance
     * @var AmazonProductAPI
     */
    protected $apapi = null;

    /**
     * Constructor
     */
    function __construct() {
        add_shortcode('amazon_link', array(&$this,'amazonLinkHandler'));
        add_shortcode('amazon_image', array(&$this,'amazonImageHandler'));
        add_shortcode('amazon_carousel', array(&$this,'amazonCarouselHandler'));
        add_shortcode('amazon_mp3_clips', array(&$this,'amazonMP3ClipsHandler'));
        add_shortcode('amazon_my_favorites', array(&$this,'amazonMyFavoritesHandler'));
        add_shortcode('amazon_search', array(&$this,'amazonSearchHandler'));
    }

    /**
     * set the APaPi library instance
     * @param <AmazonProductAPI> $apapi
     */
    public function setAPI( $apapi ) {
        $this->apapi = $apapi;
    }

    /**
     *
     * @param <type> $atts
     * @param <type> $content
     * @param <type> $code
     */
    public function amazonLinkHandler( $atts, $content=null, $code="" ) {
        extract( shortcode_atts( array( 'id'=>null, 'type' => 'ASIN', 'target' => '_blank' ), $atts ) );
        $output_str = $content;
        if( ! is_null( $id ) ) {
            $result = $this->apapi->lookup( $id, $type );
            if( $result->isSuccess() && isset( $result->Items[0] ) ) {
                $output_str = '<a href="' . urldecode($result->Items[0]->DetailPageURL) . '" target="' . $target . '">' . $content . '</a>';
            }
        }
        return $output_str;
    }

    /**
     *
     * @param <type> $atts ShortCode Attributes
     * @param <type> $content
     * @param <type> $code
     */
    public function amazonImageHandler( $atts, $content=null, $code="" ) {
        extract( shortcode_atts( array( 'id'=>null, 'size'=>'medium', 'type' => 'ASIN', 'link' => false, 'target' => '_blank' ), $atts ) );
        $output_str = $content;
        if( ! is_null( $id ) ) {
            $result = $this->apapi->lookup( $id, $type, array( AmazonProduct_ResponseGroup::ITEM_ATTRIBUTES, AmazonProduct_ResponseGroup::IMAGES ) );
            if( $result->isSuccess() && isset( $result->Items[0] ) ) {
                $size = strtolower($size );
                $image = null;
                switch( $size ) {
                    case "small":
                        $image = $result->Items[0]->SmallImage;
                        break;
                    case "large":
                        $image = $result->Items[0]->LargeImage;
                        break;
                    default :
                        $image = $result->Items[0]->MediumImage;
                        break;
                }
                $output_str = '';
                if( $link ) {
                    $output_str = '<a href="' . urldecode($result->Items[0]->DetailPageURL) . '" target="' . $target . '">';
                }
                if( ! is_null( $image ) ) {
                    $output_str .= $image->toHTML();
                } else {
                    $output_str .= $content;
                }
                if( $link ) {
                    $output_str .= '</a>';
                }
            }
        }
        return $output_str;
    }

    /**
     *
     * @param <type> $atts ShortCode Attributes
     * @param <type> $content
     * @param <type> $code
     */
    public function amazonCarouselHandler( $atts, $content=null, $code="" ) {
        $args = shortcode_atts( AmazonWidget_Carousel::getDefaultShortCodeOptions(), $atts );
        $carousel = new AmazonWidget_Carousel( $args );
        return $carousel->toHTML();
    }

    /**
     *
     * @param <type> $atts ShortCode Attributes
     * @param <type> $content
     * @param <type> $code
     */
    public function amazonMP3ClipsHandler( $atts, $content=null, $code="" ) {
        $args = shortcode_atts( AmazonWidget_MP3Clips::getDefaultShortCodeOptions(), $atts );
        $carousel = new AmazonWidget_MP3Clips( $args );
        return $carousel->toHTML();
    }

    /**
     *
     * @param <type> $atts ShortCode Attributes
     * @param <type> $content
     * @param <type> $code
     */
    public function amazonMyFavoritesHandler( $atts, $content=null, $code="" ) {
        $args = shortcode_atts( AmazonWidget_MyFavorites::getDefaultShortCodeOptions(), $atts );
        $carousel = new AmazonWidget_MyFavorites( $args );
        return $carousel->toHTML();
    }

    /**
     *
     * @param <type> $atts ShortCode Attributes
     * @param <type> $content
     * @param <type> $code
     */
    public function amazonSearchHandler( $atts, $content=null, $code="" ) {
        $args = shortcode_atts( AmazonWidget_Search::getDefaultShortCodeOptions(), $atts );
        $carousel = new AmazonWidget_Search( $args );
        return $carousel->toHTML();
    }

}