<?php
/*
 * copyright (c) 2010 MDBitz - Matthew John Denton - mdbitz.com
 *
 * This file is part of WordPress Amazon Associate Plugin.
 *
 * WordPress Amazon Associate is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * WordPress Amazon Associate is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with WordPress Amazon Associate.
 * If not, see <http://www.gnu.org/licenses/>.
*/

/**
 * Search Amazon Widget
 *
 * This file contains the class Widget_Amazon_Search
 *
 * @author Matthew John Denton <matt@mdbitz.com>
 * @package com.mdbitz.wordpress.amazon_associate.Widget.Amazon
 */

/**
 * Widget_Amazon_Search is the implemenation of the Amaozn Search
 * Widget as a WordPress Widget
 *
 * @package com.mdbitz.wordpress.amazon_associate.Widget.Amazon
 */
class Widget_Amazon_Search extends Widget_MDBitz_Base {

    /**
     * constructor
     */
    function Widget_Amazon_Search() {

        /* Widget Settings */
        $widget_settings = array( 'classname'=>'Widget_Amazon_Search', 'description'=>'Amazon Search Widget' );

        /* Widget Control Options */
        $widget_options = array ( 'width' => 300, 'height' => 600, 'id_base' => 'amazon-search-widget' );;

        parent::WP_Widget('amazon-search-widget', 'Amazon Search Widget', $widget_settings, $widget_options);
    }

    /**
     * @see WP_Widget::widget
     */
    function widget($args, $instance) {
        global $wpaa;
        echo $before_widget;
        $title = apply_filters('widget_title', $instance['widgetTitle']);
        if ( $title ) {
            echo $before_title . $title . $after_title;
        }
        $instance['tag'] = $wpaa->getAssociateId();
        AmazonWidget::Search( $instance );
        echo $after_widget;
    }

    /**
     * @see WP_Widget::update
     */
    function update($new_instance, $old_instance) {
        $instance = $old_instance;
        $instance['width'] = strip_tags($new_instance['width']);
        $instance['widgetTitle'] = strip_tags($new_instance['widgetTitle']);
        $instance['marketPlace'] = strip_tags($new_instance['marketPlace']);
        $instance['searchIndex'] = strip_tags($new_instance['searchIndex']);
        $instance['defaultSearchTerm'] = strip_tags($new_instance['defaultSearchTerm']);
        $instance['columns'] = strip_tags($new_instance['columns']);
        $instance['rows'] = strip_tags($new_instance['rows']);
        if( isset( $new_instance['showImage'] ) ) {
            $instance['showImage'] = "True";
        } else {
            $instance['showImage'] = "False";
        }
        if( isset( $new_instance['showPrice'] ) ) {
            $instance['showPrice'] = "True";
        } else {
            $instance['showPrice'] = "False";
        }
        if( isset( $new_instance['showRating'] ) ) {
            $instance['showRating'] = "True";
        } else {
            $instance['showRating'] = "False";
        }
        $instance['design'] = strip_tags($new_instance['design']);
        $instance['colorTheme'] = strip_tags($new_instance['colorTheme']);
        $instance['outerBackgroundColor'] = strip_tags($new_instance['outerBackgroundColor']);
        $instance['innerBackgroundColor'] = strip_tags($new_instance['innerBackgroundColor']);
        $instance['headerTextColor'] = strip_tags($new_instance['headerTextColor']);
        $instance['linkedTextColor'] = strip_tags($new_instance['linkedTextColor']);
        $instance['bodyTextColor'] = strip_tags($new_instance['bodyTextColor']);
        if( isset( $new_instance['roundedCorners'] ) ) {
            $instance['roundedCorners'] = "True";
        } else {
            $instance['roundedCorners'] = "False";
        }
        return $instance;
    }

    /**
     * @see WP_Widget::form
     */
    function form($instance) {
        $instance = wp_parse_args( (array) $instance, AmazonWidget_Search::getDefaultOptions() );
        $width = esc_attr($instance['width']);
        $widgetTitle = esc_attr($instance['widgetTitle']);
        $marketPlace = esc_attr($instance['marketPlace']);
        $searchIndex = esc_attr($instance['searchIndex']);
        $defaultSearchTerm = esc_attr($instance['defaultSearchTerm']);
        $columns = esc_attr($instance['columns']);
        $rows = esc_attr($instance['rows']);
        $showImage = false;
        if( $instance['showImage'] == "True" ) {
            $showImage = true;
        }
        $showPrice = false;
        if( $instance['showPrice'] == "True" ) {
            $showPrice = true;
        }
        $showRating = false;
        if( $instance['showRating'] == "True" ) {
            $showRating = true;
        }
        $design = esc_attr($instance['design']);
        $colorTheme = esc_attr($instance['colorTheme']);
        $outerBackgroundColor = esc_attr($instance['outerBackgroundColor']);
        $innerBackgroundColor = esc_attr($instance['innerBackgroundColor']);
        $headerTextColor = esc_attr($instance['headerTextColor']);
        $linkedTextColor = esc_attr($instance['linkedTextColor']);
        $bodyTextColor = esc_attr($instance['bodyTextColor']);
        $roundedCorners = false;
        if( $instance['roundedCorners'] == "True" ) {
            $roundedCorners = true;
        }
        ?>
<div>
    <h3>Basic Properties</h3>
        <?php
        echo $this->textinputWithLabel( "Widget Title:", 'widgetTitle', $widgetTitle );
        echo $this->textinputWithLabel( 'Width:', 'width', $width );
        echo $this->textinputWithLabel( 'Height:', 'height', $height );
        echo $this->selectWithLabel( 'Market Place:', 'marketPlace', AmazonWidget_Abstract::getAvailableMarkets(), $marketPlace );
        ?><h3>Widget Options</h3><?php
        echo $this->textinputWithLabel( 'Title:', 'title', $title );
        echo $this->selectWithLabel( 'Search Index:', 'searchIndex', AmazonProduct_SearchIndex::SupportedSearchIndexes(), $searchIndex );
        echo $this->textinputWithLabel( 'Default Search Term:', 'defaultSearchTerm', $defaultSearchTerm );
        echo $this->textinputWithLabel( 'Columns:', 'columns', $columns );
        echo $this->textinputWithLabel( 'Rows:', 'rows', $rows );
        echo $this->checkboxWithLabel( 'Show Image:', 'showImage', $showImage );
        echo $this->checkboxWithLabel( 'Show Price:', 'showPrice', $showPrice );
        echo $this->checkboxWithLabel( 'Show Rating:', 'showRating', $showRating );
        ?><h3>Design Options</h3><?php
        $js = "onchange=\" changeAmazonWidgetDesign( '" . $this->get_field_id('design') . "', '" . $this->get_field_id('colorTheme') . "', '" . $this->get_field_id('outerBackgroundColor') . "', '" . $this->get_field_id('innerBackgroundColor') . "', '" . $this->get_field_id('roundedCorners') . "' )\"";
        echo $this->selectWithLabel( 'Design:', 'design', AmazonWidget_Design::getAvailableDesigns(), $design, $js );
        echo $this->selectWithLabel( 'Color Theme:', 'colorTheme', AmazonWidget_Design::getDesignColorThemes( $design ), $colorTheme );
        echo $this->textinputWithLabel( 'Outer Background Color:', 'outerBackgroundColor', $outerBackgroundColor );
        echo $this->textinputWithLabel( 'Inner Background Color:', 'innerBackgroundColor', $innerBackgroundColor );
        echo $this->textinputWithLabel( 'Header Text Color:', 'headerTextColor', $headerTextColor );
        echo $this->textinputWithLabel( 'Linked Text Color:', 'linkedTextColor', $linkedTextColor );
        echo $this->textinputWithLabel( 'Body Text Color:', 'bodyTextColor', $bodyTextColor );
        echo $this->checkboxWithLabel( 'Rounded Corners:', 'roundedCorners', $roundedCorners );
        ?>
    </div>
<script type="text/javascript">
    if( window.changeAmazonDesign ) {

    } else {
        function changeAmazonWidgetDesign( id, theme_id, ob_id, ib_id, rc_id ) {
            var value = jQuery( "#" + id ).val();
            if( value == "1" ) {
                jQuery('#' + theme_id ).find('option').remove().end()
                    .append('<?php
                        $options = "";
                        $colorThemes = AmazonWidget_Design::getDesignColorThemes( "1" );
                        foreach( $colorThemes as $key => $value ) {
                            $options .= '<option value="' . $key . '" >' . $value . '</option>';
                        }
                        echo $options;
                    ?>').val('Blues');
                jQuery( "#" + ob_id).removeAttr('disabled');
                jQuery( "#" + ib_id).removeAttr('disabled');
                jQuery( "#" + rc_id).removeAttr('disabled');
            } else if ( value == "2" ) {
                jQuery('#' + theme_id).find('option').remove().end()
                    .append('<?php
                        $options = "";
                        $colorThemes = AmazonWidget_Design::getDesignColorThemes( "2" );
                        foreach( $colorThemes as $key => $value ) {
                            $options .= '<option value="' . $key . '" >' . $value . '</option>';
                        }
                        echo $options;
                    ?>').val('Default');
                jQuery( "#" + ob_id).removeAttr('disabled');
                jQuery( "#" + ib_id).removeAttr('disabled');
                jQuery( "#" + rc_id).attr('disabled','disabled');
            } else if ( value == "3" ) {
                jQuery('#' + theme_id).find('option').remove().end()
                    .append('<?php
                        $options = "";
                        $colorThemes = AmazonWidget_Design::getDesignColorThemes( "3" );
                        foreach( $colorThemes as $key => $value ) {
                            $options .= '<option value="' . $key . '" >' . $value . '</option>';
                        }
                        echo $options;
                    ?>').val('Peppermint');
                jQuery( "#" + ob_id).attr('disabled','disabled');
                jQuery( "#" + ib_id).attr('disabled','disabled');
                jQuery( "#" + rc_id).attr('disabled','disabled');
            } else if ( value == "4" ) {
                jQuery('#' + theme_id ).find('option').remove().end()
                    .append('<?php
                        $options = "";
                        $colorThemes = AmazonWidget_Design::getDesignColorThemes( "4" );
                        foreach( $colorThemes as $key => $value ) {
                            $options .= '<option value="' . $key . '" >' . $value . '</option>';
                        }
                        echo $options;
                    ?>').val('Onyx');
                jQuery( "#" + ob_id).attr('disabled','disabled');
                jQuery( "#" + ib_id).attr('disabled','disabled');
                jQuery( "#" + rc_id).attr('disabled','disabled');
            } else {
                jQuery('#' + theme_id).find('option').remove().end()
                    .append('<?php
                        $options = "";
                        $colorThemes = AmazonWidget_Design::getDesignColorThemes( "5" );
                        foreach( $colorThemes as $key => $value ) {
                            $options .= '<option value="' . $key . '" >' . $value . '</option>';
                        }
                        echo $options;
                    ?>').val('BrushedSteel');
                jQuery( "#" + ob_id).attr('disabled','disabled');
                jQuery( "#" + ib_id).attr('disabled','disabled');
                jQuery( "#" + rc_id).attr('disabled','disabled');
            }
        }
    }
    jQuery( "#<?php echo $this->get_field_id('design');?>" ).change();
    jQuery('#<?php echo $this->get_field_id('colorTheme');?>').val("<?php echo $colorTheme; ?>");
</script>
        <?php
    }

} // class Widget_Amazon_Search